import { h } from 'vue'
import { NIcon, NMenu } from 'naive-ui'
import type { MenuOption } from 'naive-ui'
import { BookmarkOutline, CaretDownOutline } from '@vicons/ionicons5'
import IconCesium from '@/components/icons/IconCesium.vue'
import IconVue from '@/components/icons/IconVue.vue'
import IconHtml from '@/components/icons/IconHtml.vue'
const menuOptions: MenuOption[] = [
  {
    label: 'Cesium',
    key: 'cesium',
    children: [
      {
        label: '鼠',
        key: 'rat',
      },
    ],
    icon: () => h(IconCesium),
  },
  {
    label: 'Vue',
    key: 'Vue',
    icon: () => h(IconVue),
  },
  {
    label: 'HTML',
    key: 'HTML',
    icon: () => h(IconHtml),
    children: [
      {
        label: '食物',
        key: 'food',
      },
      {
        label: '过去增多，未来减少',
        key: 'the-past-increases-the-future-recedes',
      },
    ],
  },
]

const renderMenuLabel = (option: MenuOption) => {
  if ('href' in option) {
    return h('a', { href: option.href, target: '_blank' }, option.label as string)
  }
  return option.label as string
}

const renderMenuIcon = (option: MenuOption) => {
  if ('icon' in option) {
    return h(NIcon, null, option.icon)
  } else {
    return h(NIcon, null, { default: () => h(option.icon ? option.icon : BookmarkOutline) })
  }
}

const expandIcon = () => {
  return h(NIcon, null, { default: () => h(CaretDownOutline) })
}
export default defineComponent({
  setup() {
    // const collapsed = ref<boolean>(true)
    return () => (
      <>
        <NMenu
          class="w-h-full"
          // collapsed={collapsed.value}
          collapsed-width={64}
          collapsed-icon-size={22}
          options={menuOptions}
          render-label={renderMenuLabel}
          render-icon={renderMenuIcon}
          expand-icon={expandIcon}
        ></NMenu>
      </>
    )
  },
})
